/*
 * event.c - construct events data.
 *
 * Copyright (C) 2024 IOPSYS Software Solutions AB. All rights reserved.
 *
 * Author: anjan.chanda@iopsys.eu
 *
 * See LICENSE file for license related information.
 *
 */

#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <stdint.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ioctl.h>
#include <net/if_arp.h>
#include <net/if.h>
#include <arpa/inet.h>

#include <json-c/json.h>
#include <libubox/blobmsg.h>
#include <libubox/blobmsg_json.h>
#include <libubox/utils.h>

#include <easy/easy.h>

#include "debug.h"
#include "util.h"
#include "timer.h"
#include "csmngr.h"


int csmngr_build_event(void *out, const char *event, va_list ap)
{
	struct blob_buf *bb = (struct blob_buf *)out;
	char ifname[16] = {0};
	va_list aq;

	va_copy(aq, ap);
	memcpy(ifname, va_arg(aq, char *), 15);
	blobmsg_add_string(bb, "ifname", ifname);
	blobmsg_add_string(bb, "event", event);

	if (!strcmp(event, CSMNGR_EVENT_ACS_END)) {
		int bandwidth = 0;
		int channel = 0;
		void *t;

		channel = (int)va_arg(aq, int);
		bandwidth = (int)va_arg(aq, int);

		t = blobmsg_open_table(bb, "data");
		blobmsg_add_u32(bb, "channel", channel);
		blobmsg_add_u32(bb, "bandwidth", bandwidth);
		blobmsg_close_table(bb, t);
	}

	va_end(aq);
	return 0;
}

